@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2014 ZNC, see the NOTICE file for details.
+# Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -128,4 +128,4 @@ proc matchattr {handle flags {channel ""}} {return 0}
 source [file dirname $::MasterFile]/binds.tcl
 
 
-PutModule "Succesfully loaded modtcl with master file: [info script]"
+PutModule "Successfully loaded modtcl with master file: [info script]"
